#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import glob
from ds_utils import ds_utils

CONFIG_FILE_DIR = "./config_files"


def clear_workload_security_links(api_utils):
    api_utils.clear_workload_security_links()


def create_workload_security_links(api_utils):
    api_utils.create_workload_security_links()


def create_policy_migration_task(api_utils):
    policy_migration_task_id = api_utils.create_policy_migration_task()
    return policy_migration_task_id


def describe_policy_migration_task(api_utils, policy_migration_task_id):
    policies = api_utils.describe_policy_migration_task(
        policy_migration_task_id)
    return policies


def get_target_computers(api_utils):
    target_computers = api_utils.get_target_computers()
    return target_computers


def list_computer_policy_id(api_utils, target_computers):
    id_lists = api_utils.list_computer_policy_id(target_computers)
    return id_lists


def create_computer_move_task(api_utils, policies, hosts):
    api_utils.create_computer_move_task(policies, hosts)


def main():
    config_files = glob.glob(CONFIG_FILE_DIR + "/*.ini")
    for config_file_path in config_files:
        api_utils = ds_utils.APIUtils(config_file_path)
        clear_workload_security_links(api_utils)
        create_workload_security_links(api_utils)

        if api_utils.policy_migration == "YES":
            policy_migration_task_id = create_policy_migration_task(api_utils)
            policies = describe_policy_migration_task(
                api_utils, policy_migration_task_id)
        elif api_utils.policy_migration == "NO":
            policies = {}
        else:
            raise Exception(
                "Error: config.iniのpolicy_migration項目にYESかNOを記載してください")

        if api_utils.target_computers_file_path == "ALL":
            target_computers = []
        elif api_utils.target_computers_file_path.lower().endswith("csv"):
            target_computers = get_target_computers(api_utils)
        else:
            raise Exception(
                "Error: config.iniのtarget_computers_file_path項目にALLかCSVファイルのファイルパスを記載してください")

        id_lists = list_computer_policy_id(api_utils, target_computers)
        create_computer_move_task(api_utils, policies, id_lists)


if __name__ == "__main__":
    main()
    print("移行タスクの作成を終了しました")
